from buildbot.plugins import *
from buildbot_common.build_helpers import *
import os
from buildbot.util import bytes2unicode
import json

__all__ = [ "configure", "E" ]

class E():
    PROJECT           = "denise"
    BUILDBOT_URL      = "https://git.immae.eu/buildbot/{}/".format(PROJECT)
    SOCKET            = "unix:/run/buildbot/{}.sock".format(PROJECT)
    PB_SOCKET         = "unix:address=/run/buildbot/{}_pb.sock".format(PROJECT)
    SSH_KEY_PATH      = "/var/lib/buildbot/buildbot_key"
    SSH_HOST_KEY      = "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIIFbhFTl2A2RJn5L51yxJM4XfCS2ZaiSX/jo9jFSdghF"

    BINGO_RELEASE_PATH  = "/var/lib/buildbot/outputs/denise/bingo"
    BINGO_BETA_PATH     = "/var/lib/buildbot/outputs/denise/bingo_beta"
    BINGO_GIT_URL       = "gitolite@git.immae.eu:perso/Denise/bingo"

    OMS_RELEASE_PATH  = "/var/lib/buildbot/outputs/denise/oms"
    OMS_BETA_PATH     = "/var/lib/buildbot/outputs/denise/oms_beta"
    OMS_GIT_URL       = "gitolite@git.immae.eu:perso/Denise/oms"

    AVENTURIERS_RELEASE_PATH = "/var/lib/buildbot/outputs/denise/aventuriers"
    AVENTURIERS_GIT_URL      = "https://git.immae.eu/perso/Denise/aventuriers.git"

    # master.cfg
    SECRETS_FILE       = os.getcwd() + "/secrets"
    LDAP_URL           = "ldaps://ldap.immae.eu:636"
    LDAP_ADMIN_USER    = "cn=buildbot,ou=services,dc=immae,dc=eu"
    LDAP_BASE          = "dc=immae,dc=eu"
    LDAP_PATTERN       = "(uid=%(username)s)"
    LDAP_GROUP_PATTERN = "(&(memberOf=cn=groups,ou=denise,cn=buildbot,ou=services,dc=immae,dc=eu)(member=%(dn)s))"
    TITLE_URL          = "https://oms.syanni.eu"
    TITLE              = "Syanni website"

class CustomBase(webhooks.base):
    def getChanges(self, request):
        try:
            content = request.content.read()
            args = json.loads(bytes2unicode(content))
        except Exception as e:
            raise ValueError("Error loading JSON: " + str(e))

        args.setdefault("comments", "")
        args.setdefault("repository", "")
        args.setdefault("author", args.get("who", "unknown"))

        return ([args], None)

def configure(c):
    c["buildbotURL"] = E.BUILDBOT_URL
    c["www"]["port"] = E.SOCKET

    c["www"]["change_hook_dialects"]["base"] = {
            "custom_class": CustomBase
            }
    c['workers'].append(worker.LocalWorker("generic-worker-denise"))

    c['schedulers'].append(hook_scheduler("DeniseBingo", timer=1))
    c['schedulers'].append(hook_scheduler("DeniseOMS", timer=1))
    c['schedulers'].append(hook_scheduler("DeniseAventuriers", timer=1))
    c['schedulers'].append(force_scheduler("force_denise", [
        "DeniseBingo_build", "DeniseOMS_build", "DeniseAventuriers_build"
        ]))

    c['builders'].append(denise_oms_factory())
    c['builders'].append(denise_bingo_factory())
    c['builders'].append(denise_aventuriers_factory())

def denise_bingo_factory():
    @util.renderer
    def bingo_run_path(props):
        if props.hasProperty("branch") and len(props["branch"]) > 0 and props["branch"] == "master":
            return "/run/denise_bingo/gunicorn.pid"
        else:
            return "/run/denise_bingo_beta/gunicorn.pid"

    @util.renderer
    def bingo_systemd_service(props):
        if props.hasProperty("branch") and len(props["branch"]) > 0 and props["branch"] == "master":
            return "denise-bingo"
        else:
            return "denise-bingo-beta"

    @util.renderer
    def bingo_url(props):
        if props.hasProperty("branch") and len(props["branch"]) > 0 and props["branch"] == "master":
            return "https://bingo.syanni.eu"
        else:
            return "https://beta.bingo.syanni.eu"

    @util.renderer
    def bingo_path(props):
        if props.hasProperty("branch") and len(props["branch"]) > 0 and props["branch"] == "master":
            return E.BINGO_RELEASE_PATH
        else:
            return E.BINGO_BETA_PATH

    factory = util.BuildFactory()
    factory.addStep(steps.Git(logEnviron=False, repourl=E.BINGO_GIT_URL,
        submodules=True, sshPrivateKey=open(E.SSH_KEY_PATH).read().rstrip(),
        sshHostKey=E.SSH_HOST_KEY, mode="full", method="copy"))
    factory.addStep(steps.MasterShellCommand(command=util.Interpolate("rm -rf %(kw:bingo_path)s", bingo_path=bingo_path)))
    factory.addStep(steps.DirectoryUpload(workersrc="../source",
        masterdest=bingo_path,
        url=bingo_url))
    factory.addStep(steps.MasterShellCommand(command=util.Interpolate("chmod -R a+rX %(kw:bingo_path)s", bingo_path=bingo_path)))
    factory.addStep(steps.MasterShellCommand(command=util.Interpolate("/run/wrappers/bin/sudo systemctl restart %(kw:bingo_service)s.service", bingo_service=bingo_systemd_service)))

    return util.BuilderConfig(name="DeniseBingo_build", workernames=["generic-worker-denise"], factory=factory)

def denise_oms_factory():
    @util.renderer
    def oms_run_path(props):
        if props.hasProperty("branch") and len(props["branch"]) > 0 and props["branch"] == "master":
            return "/run/denise_oms/gunicorn.pid"
        else:
            return "/run/denise_oms_beta/gunicorn.pid"

    @util.renderer
    def oms_systemd_service(props):
        if props.hasProperty("branch") and len(props["branch"]) > 0 and props["branch"] == "master":
            return "denise-oms"
        else:
            return "denise-oms-beta"

    @util.renderer
    def oms_url(props):
        if props.hasProperty("branch") and len(props["branch"]) > 0 and props["branch"] == "master":
            return "https://oms.syanni.eu"
        else:
            return "https://beta.oms.syanni.eu"

    @util.renderer
    def oms_path(props):
        if props.hasProperty("branch") and len(props["branch"]) > 0 and props["branch"] == "master":
            return E.OMS_RELEASE_PATH
        else:
            return E.OMS_BETA_PATH

    factory = util.BuildFactory()
    factory.addStep(steps.Git(logEnviron=False, repourl=E.OMS_GIT_URL,
        submodules=True, sshPrivateKey=open(E.SSH_KEY_PATH).read().rstrip(),
        sshHostKey=E.SSH_HOST_KEY, mode="full", method="copy"))
    factory.addStep(steps.MasterShellCommand(command=util.Interpolate("rm -rf %(kw:oms_path)s", oms_path=oms_path)))
    factory.addStep(steps.DirectoryUpload(workersrc="../source",
        masterdest=oms_path,
        url=oms_url))
    factory.addStep(steps.MasterShellCommand(command=util.Interpolate("chmod -R a+rX %(kw:oms_path)s", oms_path=oms_path)))
    factory.addStep(steps.MasterShellCommand(command=util.Interpolate("/run/wrappers/bin/sudo systemctl restart %(kw:oms_service)s.service", oms_service=oms_systemd_service)))

    return util.BuilderConfig(name="DeniseOMS_build", workernames=["generic-worker-denise"], factory=factory)

def denise_aventuriers_factory():
    path_env = {
            "PATH": os.environ["BUILDBOT_PATH_Aventuriers"] + ":${PATH}",
            "TZ": "Europe/Paris",
            }

    factory = util.BuildFactory()
    factory.addStep(steps.Git(logEnviron=False, repourl=E.AVENTURIERS_GIT_URL,
        submodules=True, mode="full", method="fresh"))
    factory.addStep(steps.ShellCommand(name="build files",
        logEnviron=False, haltOnFailure=True, workdir="build",
        env=path_env, command=["make", "tout", "encyclo"]))
    factory.addStep(steps.MasterShellCommand(command="rm -rf {}".format(E.AVENTURIERS_RELEASE_PATH)))
    factory.addStep(steps.DirectoryUpload(workersrc="../build/html",
        masterdest=E.AVENTURIERS_RELEASE_PATH,
        url="https://aventuriers.syanni.eu"))
    factory.addStep(steps.FileUpload(name="upload epub file", workersrc="aventuriers.epub",
        workdir="build", masterdest=E.AVENTURIERS_RELEASE_PATH + "/aventuriers.epub",
        url="https://aventuriers.syanni.eu/aventuriers.epub", mode=0o644))
    factory.addStep(steps.FileUpload(name="upload mobi file", workersrc="aventuriers.mobi",
        workdir="build", masterdest=E.AVENTURIERS_RELEASE_PATH + "/aventuriers.mobi",
        url="https://aventuriers.syanni.eu/aventuriers.mobi", mode=0o644))
    factory.addStep(steps.FileUpload(name="upload pdf file", workersrc="aventuriers.pdf",
        workdir="build", masterdest=E.AVENTURIERS_RELEASE_PATH + "/aventuriers.pdf",
        url="https://aventuriers.syanni.eu/aventuriers.pdf", mode=0o644))
    factory.addStep(steps.FileUpload(name="upload encyclo pdf file", workersrc="encyclo.pdf",
        workdir="build", masterdest=E.AVENTURIERS_RELEASE_PATH + "/encyclo.pdf",
        url="https://aventuriers.syanni.eu/encyclo.pdf", mode=0o644))
    factory.addStep(steps.MasterShellCommand(command="chmod -R a+rX {}".format(E.AVENTURIERS_RELEASE_PATH)))

    return util.BuilderConfig(name="DeniseAventuriers_build", workernames=["generic-worker-denise"], factory=factory)
