let
set = {
  # adatped from nixpkgs/nixos/modules/services/web-servers/apache-httpd/default.nix
  httpdInte  = import ../websites/httpd-service-builder.nix { httpdName = "Inte"; withUsers = false; };
  httpdProd  = import ../websites/httpd-service-builder.nix { httpdName = "Prod"; withUsers = false; };
  httpdTools = import ../websites/httpd-service-builder.nix { httpdName = "Tools"; withUsers = true; };

  databases  = ./databases;
  mariadb    = ./databases/mariadb.nix;
  openldap   = ./databases/openldap;
  postgresql = ./databases/postgresql.nix;
  redis      = ./databases/redis.nix;
  postgresqlReplication = ./databases/postgresql_replication.nix;
  mariadbReplication = ./databases/mariadb_replication.nix;
  redisReplication = ./databases/redis_replication.nix;
  openldapReplication = ./databases/openldap_replication.nix;

  websites = ./websites;
  gemini = ./gemini;


  # Personal websites
  bakeerCloud = ./websites/bakeer/cloud.nix;

  capitainesLandingPages = ./websites/capitaines/landing_pages.nix;

  chloeInte = ./websites/chloe/integration.nix;
  chloeProd = ./websites/chloe/production.nix;

  cipcaSympa = ./websites/cip-ca/sympa.nix;

  connexionswingInte = ./websites/connexionswing/integration.nix;
  connexionswingProd = ./websites/connexionswing/production.nix;

  deniseDenisejeromeProd = ./websites/denise/denisejerome.nix;
  deniseEvariste = ./websites/denise/evariste.nix;
  deniseOMS = ./websites/denise/oms.nix;
  deniseBingo = ./websites/denise/bingo.nix;
  deniseAventuriers = ./websites/denise/aventuriers.nix;
  deniseProduction = ./websites/denise/production.nix;

  emiliaMoodle = ./websites/emilia/moodle.nix;
  emiliaAtelierFringant = ./websites/emilia/atelierfringant.nix;

  florianApp = ./websites/florian/app.nix;
  florianInte = ./websites/florian/integration.nix;
  florianProd = ./websites/florian/production.nix;

  immaeProd = ./websites/immae/production.nix;
  immaeRelease = ./websites/immae/release.nix;
  immaeTemp = ./websites/immae/temp.nix;

  isabelleAtenInte = ./websites/isabelle/aten_integration.nix;
  isabelleAtenProd = ./websites/isabelle/aten_production.nix;
  isabelleIridologie = ./websites/isabelle/iridologie.nix;

  jeromeNaturaloutil = ./websites/jerome/naturaloutil.nix;

  leilaProd = ./websites/leila/production.nix;

  ludivineInte = ./websites/ludivine/integration.nix;
  ludivineProd = ./websites/ludivine/production.nix;

  nassimeProd = ./websites/nassime/production.nix;

  nathVillon = ./websites/nath/villon.nix;

  papaMaisonBbc = ./websites/papa/maison_bbc.nix;
  papaSurveillance = ./websites/papa/surveillance.nix;

  patrickFodellaEcolyeu = ./websites/patrick_fodella/ecolyeu.nix;
  patrickFodellaAltermondia = ./websites/patrick_fodella/altermondia.nix;

  piedsjalouxInte = ./websites/piedsjaloux/integration.nix;
  piedsjalouxProd = ./websites/piedsjaloux/production.nix;

  ressourcerieBanonProd = ./websites/ressourcerie_banon/production.nix;
  ressourcerieBanonCloud = ./websites/ressourcerie_banon/cloud.nix;
  ressourcerieBanonCryptpad = ./websites/ressourcerie_banon/cryptpad.nix;

  richieProd = ./websites/richie/production.nix;

  sydenPeertube = ./websites/syden/peertube.nix;

  teliotortayProd = ./websites/telio_tortay/production.nix;

  # Tools
  assetsTools = ./websites/tools/assets;
  cloudTool = ./websites/tools/cloud;
  cloudFarmTool = ./websites/tools/cloud/farm.nix;
  cryptpadTool = ./websites/tools/cryptpad;
  cryptpadFarmTool = ./websites/tools/cryptpad/farm.nix;
  commentoTool = ./websites/tools/commento;
  davTool = ./websites/tools/dav;
  vpnTool = ./websites/tools/vpn;
  dbTool = ./websites/tools/db;
  diasporaTool = ./websites/tools/diaspora;
  etherTool = ./websites/tools/ether;
  gitTool = ./websites/tools/git;
  imTool = ./websites/tools/im;
  mastodonTool = ./websites/tools/mastodon;
  mgoblinTool = ./websites/tools/mgoblin;
  peertubeTool = ./websites/tools/peertube;
  performanceTool = ./websites/tools/performance;
  toolsTool = ./websites/tools/tools;
  mailTool = ./websites/tools/mail;
  statsTool = ./websites/tools/stats;

  # Games
  codenamesGame = ./websites/tools/games/codenames;
  terraformingMarsGame = ./websites/tools/games/terraforming-mars;

  mail = ./mail;

  buildbot = ./buildbot;
  certificates = ./certificates.nix;
  gitolite = ./gitolite;
  irc = ./irc.nix;
  pub = ./pub;
  tasks = ./tasks;
  dns = ./dns.nix;
  ftp = ./ftp.nix;
  mpd = ./mpd.nix;
  ejabberd = ./ejabberd;
  ssh = ./ssh;
  monitoring = ./monitoring;
  status = ./monitoring/status.nix;
  status_engine = ./monitoring/status_engine.nix;
  vpn = ./vpn;

  environment = ./environment.nix;
  system = ./system.nix;
  loginctl-linger = ./loginctl-linger.nix;
};
in
builtins.listToAttrs (map (attr: { name = "priv${attr}"; value = set.${attr}; }) (builtins.attrNames set))
