{ lib, pkgs, config,  ... }:
let
  adminer = pkgs.callPackage ../commons/adminer.nix { inherit config; };
  cfg = config.myServices.websites.florian.integration;
  varDir = "/var/lib/ftp/florian/www.ft.immae.dev";
  env = config.myEnv.websites.florian;
in {
  options.myServices.websites.florian.integration.enable = lib.mkEnableOption "enable Florian's website integration";

  config = lib.mkIf cfg.enable {
    security.acme.certs."ftp".extraDomains."ft.immae.dev" = null;

    services.websites.env.integration.modules = adminer.apache.modules;
    services.websites.env.integration.vhostConfs.florian_integration = {
      certName    = "integration";
      addToCerts  = true;
      hosts       = [ "www.ft.immae.dev" ];
      root        = varDir;
      extraConfig = [
        (adminer.apache.vhostConf null)
        ''
        ServerAdmin ${env.server_admin}

        <Directory ${varDir}>
          DirectoryIndex index.php index.htm index.html
          Options Indexes FollowSymLinks MultiViews Includes
          AllowOverride None
          Require all granted
        </Directory>
          ''
      ];
    };
  };
}
